@@ -113,7 +113,7 @@ def mkplot(ax: Any = None,
         # Reset the PHA to being empty
         if empty_pha:
             try:
-                ax.pha = PlotHoldingArea()
+                ax.pha = PlotHoldingArea()   # type: ignore
             except AttributeError:
                 pass
     return fig, ax
@@ -178,11 +178,10 @@ def mkinset(ax: Any,
             show_zoom: bool = True,
             parent_corners: Tuple[str, str] = ("sw", "se"),
             inset_corners: Tuple[str, str] = ("sw", "se"),
-            plot_options: Optional[dict] = None,
             inset_options: Optional[dict] = None,
             ) -> Any:
-    """Constructs an inset on a given Axes instance and plots any staged
-    spectra on the inset Axes.
+    """Creates an inset Axes on a given Axes instance. Spectra can be staged on
+    this Axes, and `mkplot` can be called, just as usual.
 
     Parameters
     ----------
@@ -204,9 +203,6 @@ def mkinset(ax: Any,
         "northwest", "sw", "se", "ne", "nw"}.
     inset_corners : (str, str), optional
         Corners of the inset axes to draw the zoom lines to.
-    plot_options : dict, optional
-        Dictionary of options passed to `mkplot()`, which is in turn passed to
-        either |plot| or |contour|.
     inset_options : dict, optional
         Dictionary of options passed to |mark_inset|.
 
@@ -219,8 +215,6 @@ def mkinset(ax: Any,
     ax = ax or plt.gca()
     # Generate inset axes
     inset_ax = ax.inset_axes([*pos, *size], transform=transform)
-    plot_options = plot_options or {}
-    # mkplot(ax=inset_ax, xlabel="", ylabel="", **plot_options)
 
     # Convert the strings to numbers
     def convert_corner(ax: Any, cornerstr: str, is_inset: bool):
@@ -302,7 +296,7 @@ class PlotHoldingArea():
         self.colors_1d = self._color_generator_1d()
         self.colors_2d = self._color_generator_2d()
 
-    def _color_generator_1d(self) -> Iterator[str]:
+    def _color_generator_1d(self) -> Iterator[MplColor]:
         """Yields colors one at a time from the current palette."""
         yield from cycle(sns.color_palette(_current_palette))
 
@@ -522,13 +516,14 @@ class PlotObject1D():
 
 def _mkplot1d(ax: Any = None,
               style: str = "1d",
-              tight_layout: bool = True,
+              tight_layout: Optional[bool] = None,
               stacked: bool = False,
               voffset: Union[Sequence, float] = 0,
               hoffset: Union[Sequence, float] = 0,
               title: OS = None,
               autolabel: str = "nucl",
               xlabel: OS = None,
+              ylabel: OS = None,
               legend_loc: Any = "best",
               units: str = "ppm",
               ) -> Tuple[Any, Any]:
@@ -545,8 +540,11 @@ def _mkplot1d(ax: Any = None,
     style : str, optional
         Plot style to use. By default this is ``1d``. For the list of plot
         styles, see `style_axes()`.
-    tight_layout : bool, optional (default True)
-        Whether to call plt.tight_layout() after constructing the plot.
+    tight_layout : bool, optional
+        Whether to call plt.tight_layout() after constructing the plot. By
+        default this is set to True unless the Figure has been set up with
+        ``constrained_layout`` (see matplotlib's
+        :std:doc:`tutorials/intermediate/constrainedlayout_guide`).
     stacked : bool, optional
         True to make spectra tightly stacked vertically (i.e. not
         superimposed). If True, overrides any value passed in *voffset*.
@@ -571,13 +569,15 @@ def _mkplot1d(ax: Any = None,
     title : str, optional
         Plot title.
     autolabel : str, optional (default: "nucl")
-        Automatic label to use for the *x*-axis. The only option available now
-        is ``nucl`` (the default), which generates a LaTeX representation of
-        the nucleus of the first staged spectrum (e.g. for a proton spectrum,
-        using this would automatically generate the *x*-axis label
-        ``r"$\\rm ^{1}H$ (ppm)"``).
+        Automatic label to use for the *x*-axis (the *y*-axis is always set to
+        empty). The only option available now is ``nucl`` (the default), which
+        generates a LaTeX representation of the nucleus of the first staged
+        spectrum (e.g. for a proton spectrum, using this would automatically
+        generate the *x*-axis label ``r"$\\rm ^{1}H$ (ppm)"``).
     xlabel : str, optional
         *x*-Axis label. Overrides the autolabel parameter if given.
+    ylabel : str, optional
+        *y*-Axis label. Overrides the autolabel parameter if given.
     legend_loc : str or (float, float), optional
         Location to place the legend. This is passed as the *loc* parameter to
         |legend|; see the documentation there for the available options.
@@ -596,7 +596,8 @@ def _mkplot1d(ax: Any = None,
 
     See Also
     --------
-    penguins.mkplot : The appropriate interface for plot construction.
+    penguins.mkplot : You should call ``pg.mkplot(ax)`` instead of using this
+        ``_mkplot1d`` function directly.
     """
     # Flag that determines whether ax.legend is called. This will be set to
     # True if we find any PlotObject1D with a non-empty label.
@@ -658,7 +659,7 @@ def _mkplot1d(ax: Any = None,
     else:
         if autolabel == "nucl":
             xlabel = ax.pha.plot_objs[0].dataset.nuclei_to_str()
-            xlabel += " (ppm)"
+            xlabel += f" ({units})"   # type: ignore
         else:
             raise ValueError(f"Invalid value '{autolabel}' given for "
                              "parameter autolabel.")
@@ -667,11 +668,18 @@ def _mkplot1d(ax: Any = None,
     if title:
         ax.set_title(title)
     ax.set_xlabel(xlabel)
+    if ylabel:
+        ax.set_ylabel(ylabel)
     if not ax.xaxis_inverted():
         ax.invert_xaxis()
     if make_legend:
         ax.legend(loc=legend_loc)
     # Apply axis styles.
+    if tight_layout is None:
+        try:
+            tight_layout = not ax.figure.get_constrained_layout()
+        except AttributeError:  # matplotlib < 3.4
+            tight_layout = True
     style_axes(ax, style=style, tight_layout=tight_layout)
     return ax.figure, ax
 
@@ -917,7 +925,7 @@ def _stage2d(dataset: ds.Dataset2D,
 
 def _mkplot2d(ax: Any = None,
               style: str = "2d",
-              tight_layout: bool = True,
+              tight_layout: Optional[bool] = None,
               offset: Tuple[float, float] = (0, 0),
               title: OS = None,
               autolabel: str = "nucl",
@@ -940,8 +948,11 @@ def _mkplot2d(ax: Any = None,
     style : str, optional
         Plot style to use. By default this is ``2d``. For the list of plot
         styles, see `style_axes()`.
-    tight_layout : bool, optional (default True)
-        Whether to call plt.tight_layout() after constructing the plot.
+    tight_layout : bool, optional
+        Whether to call plt.tight_layout() after constructing the plot. By
+        default this is set to True unless the Figure has been set up with
+        ``constrained_layout`` (see matplotlib's
+        :std:doc:`tutorials/intermediate/constrainedlayout_guide`).
     offset : (float, float), optional
         Amount to offset successive spectra by in units of ppm, provided as
         *(f1_offset, f2_offset)*.
@@ -981,7 +992,8 @@ def _mkplot2d(ax: Any = None,
 
     See Also
     --------
-    penguins.mkplot : The appropriate interface for plot construction.
+    penguins.mkplot : You should call ``pg.mkplot(ax)`` instead of using this
+        ``_mkplot1d`` function directly.
     """
     make_legend = False
     legend_colors, legend_labels = [], []
@@ -1029,9 +1041,9 @@ def _mkplot2d(ax: Any = None,
             # This is the default case, because the default parameters are
             # xlabel=None, ylabel=None, autolabel="nucl".
             xlabel = ax.pha.plot_objs[0].dataset.nuclei_to_str()[1]
-            xlabel += f" ({f2_units})"
+            xlabel += f" ({f2_units})"   # type: ignore
             ylabel = ax.pha.plot_objs[0].dataset.nuclei_to_str()[0]
-            ylabel += f" ({f1_units})"
+            ylabel += f" ({f1_units})"   # type: ignore
         elif autolabel == "f1f2":
             xlabel = f"$f_2$ ({f2_units})"
             ylabel = f"$f_1$ ({f1_units})"
@@ -1052,6 +1064,12 @@ def _mkplot2d(ax: Any = None,
         ax.set_title(title)
     ax.set_xlabel(xlabel)
     ax.set_ylabel(ylabel)
+    # Determine tight_layout
+    if tight_layout is None:
+        try:
+            tight_layout = not ax.figure.get_constrained_layout()
+        except AttributeError:  # matplotlib < 3.4
+            tight_layout = True
     # Apply other styles.
     style_axes(ax, style=style, tight_layout=tight_layout)
 
@@ -1067,7 +1085,7 @@ def _mkplot2d(ax: Any = None,
 def _find_baselev(dataset: ds.Dataset2D,
                   increment: float = None,
                   nlev: int = 4,
-                  ) -> float:
+                  ) -> OF:
     """Create an interactive slider window to see the effect of changing
     *baselev* on the displayed spectrum.
 
@@ -1190,15 +1208,16 @@ def _find_baselev(dataset: ds.Dataset2D,
         fval = 10 ** baselev_slider.val
         fval_short = f"{fval:.2e}".replace("e+0", "e")
         print(f"The final base level was:   {fval:.2f} (or {fval_short})\n")
-    plt.close("all")
-
-    return fval if okay else None
+        plt.close("all")
+        return fval
+    else:
+        return None
 
 
 # -- Matplotlib and Seaborn wrappers --------------------------
 
 @export
-def subplots(*args, **kwargs) -> None:
+def subplots(*args, **kwargs) -> Tuple[Any, Any]:
     """Direct wrapper around |subplots|.
     """
     return plt.subplots(*args, **kwargs)
@@ -1354,7 +1373,7 @@ def set_palette(palette: Union[str, List[str]],
 
 @export
 def color_palette(palette: Optional[Union[str, List[str]]] = None,
-                  ) -> List[str]:
+                  ) -> Any:
     """Returns a list of colors corresponding to a color palette. If *palette*
     is not provided, returns the colors in the current color palette.
 
